@@ -2,21 +2,20 @@ from typing import Callable, Tuple, Union, overload
 from itertools import accumulate, repeat, chain
 from torch.nn import Module
 
+from .functools import Reduce
 
-class Accumulate(Module):
-    """Accumulate input using function, see itertools.accumulate
+
+class Accumulate(Reduce):
+    """Accumulate input using function, see itertools.accumulate. 
+    Note that `initializer` is a positional-only argument, same as in Reduce and functools.reduce,
+    in contrast to itertools.accumulate
     """
-    @overload
-    def __init__(self, function: Callable, /) -> None: ...
-    @overload
-    def __init__(self, function: Callable, *, initial) -> None: ...
-    def __init__(self, *args, **kwargs) -> None:
-        super().__init__()
-        self.args = args
-        self.kwargs = kwargs
-
+    
     def forward(self, input: Tuple):
-        return tuple(accumulate(input, *self.args, **self.kwargs))
+        if hasattr(self, 'initial'):
+            return tuple(accumulate(input, self.function, initial=self.initial))
+        
+        return tuple(accumulate(input, self.function))
 
 
 class Repeat(Module):
